Enum AxisRelativeDirection
#[non_exhaustive]#[repr(u32)]pub enum AxisRelativeDirection {
Identical = 0,
Inverted = 1,
}Available on crate feature
wayland and Linux only.Expand description
axis relative direction
This specifies the direction of the physical motion that caused a wl_pointer.axis event, relative to the wl_pointer.axis direction.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Identical = 0
physical motion matches axis direction
Inverted = 1
physical motion is the inverse of the axis direction