Enum AxisSource
#[non_exhaustive]#[repr(u32)]pub enum AxisSource {
Wheel = 0,
Finger = 1,
Continuous = 2,
WheelTilt = 3,
}wayland and Linux only.Expand description
axis source types
Describes the source types for axis events. This indicates to the client how an axis event was physically generated; a client may adjust the user interface accordingly. For example, scroll events from a “finger” source may be in a smooth coordinate space with kinetic scrolling whereas a “wheel” source may be in discrete steps of a number of lines.
The “continuous” axis source is a device generating events in a continuous coordinate space, but using something other than a finger. One example for this source is button-based scrolling where the vertical motion of a device is converted to scroll events while a button is held down.
The “wheel tilt” axis source indicates that the actual device is a wheel but the scroll event is not caused by a rotation but a (usually sideways) tilt of the wheel.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Wheel = 0
a physical wheel rotation
Finger = 1
finger on a touch surface
Continuous = 2
continuous coordinate space
WheelTilt = 3
a physical wheel tilt